---
title: <span class="badge object-type-scalar"></span> Ampere
---
# <span class="badge object-type-scalar"></span> Ampere

Energy: Ampere (A)

## Definition

```python
# Energy: Ampere (A)
Ampere: typing.Literal["amp"] = "amp"
```
